@@ -5,17 +5,19 @@
 
 > Caching structures and simplified function memoization
 
-`cached` provides implementations of several caching structures as well as a handy macro
+`cached` provides implementations of several caching structures as well as a handy macros
 for defining memoized functions.
 
-Memoized functions defined using [`#[cached]`](proc_macro::cached)/[`#[once]`](proc_macro::once)/[`#[io_cached]`](proc_macro::io_cached)/[`cached!`](macros) macros are thread-safe with the backing
+Memoized functions defined using [`#[cached]`](proc_macro::cached)/[`#[once]`](proc_macro::once)/[`#[io_cached]`](proc_macro::io_cached)/[`cached!`](crate::macros) macros are thread-safe with the backing
 function-cache wrapped in a mutex/rwlock, or externally synchronized in the case of `#[io_cached]`.
 By default, the function-cache is **not** locked for the duration of the function's execution, so initial (on an empty cache)
 concurrent calls of long-running functions with the same arguments will each execute fully and each overwrite
 the memoized value as they complete. This mirrors the behavior of Python's `functools.lru_cache`. To synchronize the execution and caching
 of un-cached arguments, specify `#[cached(sync_writes = true)]` / `#[once(sync_writes = true)]` (not supported by `#[io_cached]`.
 
-See [`cached::stores` docs](stores) cache stores available.
+- See [`cached::stores` docs](https://docs.rs/cached/latest/cached/stores/index.html) cache stores available.
+- See [`proc_macro`](https://docs.rs/cached/latest/cached/proc_macro/index.html) for more procedural macro examples.
+- See [`macros`](https://docs.rs/cached/latest/cached/macros/index.html) for more declarative macro examples.
 
 **Features**
 
@@ -27,9 +29,8 @@ See [`cached::stores` docs](stores) cache stores available.
 - `redis_tokio`: Include async Redis support using `tokio` and `tokio` tls support
 
 
-This crate provides procedural and declarative macros, in `cached::proc_macro` and `cached::macros`.
 The procedural macros (`#[cached]`, `#[once]`, `#[io_cached]`) offer more features, including async support.
-See the [`proc_macro`] and [`macros`] modules for more samples, and the
+See the [`proc_macro`](crate::proc_macro) and [`macros`](crate::macros) modules for more samples, and the
 [`examples`](https://github.com/jaemk/cached/tree/master/examples) directory for runnable snippets.`
 
 Any custom cache that implements `cached::Cached`/`cached::CachedAsync` can be used with the `#[cached]`/`#[once]`/`cached!` macros in place of the built-ins.
